@@ -35,7 +35,9 @@ from .zsys import windows_else
 
 
 # zmongo
-from .zmongo import MongoConfig, mongo_connect
+from .zmongo import MongoConfig
+from .zmongo import mongo_connect
+from .zmongo import mongo_collection
 
 
 # zmysql
@@ -80,9 +82,6 @@ from .zjson import jsondumps
 from .ztime import get_date
 from .ztime import get_today
 from .ztime import get_month
-from .ztime import trans_datetime_to_java_timestamp
-from .ztime import get_begin_datetime
-from .ztime import get_end_datetime
 
 
 # zalioss
